California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 56 - STATE BUDGET, RELATED TAXES, AND RESERVE. VOTING REQUIREMENTS. PENALTIES. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1254038 | CALIFORNIANS FOR BUDGET ACCOUNTABILITY - YES ON 56 - A COALITION OF THE LEAGUE OF WOMEN VOTERS, FIREFIGHTERS, EDUCATORS, PARENTS, HEALTHCARE WORKERS, SENIORS, FACULTY MEMBERS, AND PUBLIC AND SCHOOL E | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1254104 | CALIFORNIANS AGAINST HIGHER TAXES - NO ON 56, A COALITION OF TAXPAYERS, CONSUMERS, BUSINESSES, RETAILERS | OPPOSE